.. _packaged_libs:

Pre-packaged libraries
======================

A lot of pre-packaged CSS and Javascript libraries are available on the PyPI
and are maintained by the Fanstatic community. These can be installed into your
project right away using ``easy_install``, ``pip``, ``buildout`` or by
specifying them in ``setup_requires`` in ``setup.py`` within your
``setuptools``-compatible project.  No more complicated installation
instructions, just reuse a CSS or Javascript library like you reuse Python
libraries.

Here's a list of currently available libraries:

.. list-table::

    * - **package**
      - **library**
      - **source**

    * - :pypi:`css.css3githubbuttons`
      - `CSS3 GitHub Buttons <https://github.com/necolas/css3-github-buttons>`_
      - `GitHub <https://github.com/davidjb/css.css3githubbuttons>`__

    * - :pypi:`js.ace`
      - `Ajax.org Cloud9 Editor <https://github.com/ajaxorg/ace>`_
      - `Bitbucket <https://bitbucket.org/fanstatic/js.ace>`__

    * - :pypi:`js.amcharts`
      - `amCharts <http://www.amcharts.com>`_
      - `GitHub <https://github.com/securactive/js.amcharts>`__

    * - :pypi:`js.backbone`
      - `Backbone <http://backbonejs.org/>`_
      - `GitHub <https://github.com/podhmo/js.backbone>`__

    * - :pypi:`js.bootstrap`
      - `Bootstrap, from Twitter <http://twitter.github.com/bootstrap/index.html>`_
      - `GitHub <https://github.com/RedTurtle/js.bootstrap>`__

    * - :pypi:`js.chosen`
      - `Chosen <http://harvesthq.github.com/chosen/>`_
      - ?

    * - :pypi:`js.ckeditor`
      - `CKEditor <http://ckeditor.com/>`_
      - ?

    * - :pypi:`js.classy`
      - `Classy - Classes for JavaScript <http://classy.pocoo.org/>`_
      - `Bitbucket <https://bitbucket.org/fanstatic/js.classy>`__

    * - :pypi:`js.d3`
      - `D3.js (Data Driven Documents) <http://d3js.org/>`_
      - `GitHub <https://github.com/fanstatic/js.d3/>`__

    * - :pypi:`js.d3_cloud`
      - `D3-Cloud <http://www.jasondavies.com/wordcloud/>`_ (`Wordle
        <http://wordle.net>`_-style layout for D3) 
      - `GitHub <http://github.com/davidjb/js.d3_cloud/>`__

    * - :pypi:`js.extjs`
      - _`ExtJS`: http://www.sencha.com/products/js/
      - `Bitbucket <http://bitbucket.org/fanstatic/js.extjs>`__

    * - :pypi:`js.galleriffic`
      - `Galleriffic <http://www.twospy.com/galleriffic>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.yui>`__

    * - :pypi:`js.leaflet`
      - `Leaflet <http://leafletjs.com/>`_
      - `GitHub <https://github.com/davidjb/js.leaflet>`__

    * - :pypi:`js.jquery_datalink`
      - the jQuery plugin `Datalink <https://github.com/nje/jquery-datalink>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.jquery_datalink>`__

    * - :pypi:`js.jquery_datatables`
      - the jQuery plugin `DataTable <http://www.datatables.net>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.jquery_datatables>`__

    * - :pypi:`js.jquery_expandbox`
      - `jquery.expandBox <http://projects.stephane-klein.info/jquery.expandBox/>`_
      - `Bitbucket <https://bitbucket.org/fanstatic/js.jquery_expandbox>`__

    * - :pypi:`js.jquery_form`
      - the jQuery plugin `Form <http://jquery.malsup.com/form>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.jquery_form>`__

    * - :pypi:`js.jquery_jcrop`
      - `JCrop - Image Cropping Plugin for JQuery
        <http://deepliquid.com/content/Jcrop.html>`_
      - `GitHub <https://github.com/davidjb/js.jquery_jcrop>`__

    * - :pypi:`js.jquery_jgrowl`
      - `jGrowl <http://stanlemon.net/projects/jgrowl.html>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.jquery_jgrowl>`__

    * - :pypi:`js.jquery_jqote2`
      - `jquery.jqote2 <https://github.com/aefxx/jQote2>`_
      - `Bitbucket <https://bitbucket.org/fanstatic/js.jquery_jqote2>`__

    * - :pypi:`js.jquery_json`
      - the jQuery plugin `jquery-json <http://code.google.com/p/jquery-json/>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.jquery_json>`__

    * - :pypi:`js.jquery_jstree`
      - the jQuery plugin `JsTree <http://www.jstree.com/>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.jquery_jstree>`__

    * - :pypi:`js.jquery_metadata`
      - `jQuery Metadata <http://plugins.jquery.com/project/metadata>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.jquery_metadata>`__

    * - :pypi:`js.jquery_qtip`
      - `jquery.qTip <http://craigsworks.com/projects/qtip/>`_
      - `Bitbucket <https://bitbucket.org/fanstatic/js.jquery_qtip>`__

    * - :pypi:`js.jquery_qunit`
      - the jQuery plugin `QUnit <http://docs.jquery.com/Qunit>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.jquery_qunit>`__

    * - :pypi:`js.jquery_slimbox`
      - the jQuery plugin `Slimbox <http://www.digitalia.be/software/slimbox2>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.jquery_slimbox>`__

    * - :pypi:`js.jquery_tablesorter`
      - the jQuery plugin `tablesorter <http://tablesorter.com>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.jquery_tablesorter>`__

    * - :pypi:`js.jquery_textchildren`
      - the jQuery plugin `Text Children <http://plugins.learningjquery.com/textchildren>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.jquery_textchildren>`__

    * - :pypi:`js.jquery_tinyscrollbar`
      - the jQuery plugin `Tiny Scrollbar <http://baijs.nl/tinyscrollbar/>`_
      - `Bitbucket <http://bitbucket.org/gocept/js.jquery_tinyscrollbar>`__

    * - :pypi:`js.jquery_tools`
      - `jQuery tools <http://flowplayer.org/tools/index.html>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.jquery_tools>`__

    * - :pypi:`js.jquery_tooltip`
      - the jQuery plugin `Tooltip <http://bassistance.de/jquery-plugins/jquery-plugin-tooltip>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.jquery_tooltip>`__

    * - :pypi:`js.jquery_utils`
      - `jQuery Utils <http://code.google.com/p/jquery-utils/>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.jquery_utils>`__

    * - :pypi:`js.jquery`
      - `jQuery <http://jquery.com>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.jquery>`__

    * - :pypi:`js.jqueryui`
      - `jQuery UI <http://jqueryui.com>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.jqueryui>`__

    * - :pypi:`js.knockback`
      - `Knockback.js <http://kmalakoff.github.com/knockback/>`_
      - `Bitbucket <https://bitbucket.org/gocept/js.knockback>`__

    * - :pypi:`js.knockout`
      - `Knockout <http://knockoutjs.com/>`_
      - `Bitbucket <https://bitbucket.org/gocept/js.knockout>`__

    * - :pypi:`js.lesscss`
      - `less.js <http://lesscss.org/>`_
      - `Bitbucket <https://bitbucket.org/fanstatic/js.lesscss>`__

    * - :pypi:`js.lightbox`
      - `jquery lightbox <http://leandrovieira.com/projects/jquery/lightbox/>`_
      - `GitHub <https://github.com/amleczko/js.lightbox>`__

    * - :pypi:`js.mochikit`
      - `Mochikit <http://mochikit.org/>`_
      - `Bitbucket <https://bitbucket.org/gocept/js.mochikit>`__

    * - :pypi:`js.modernizr`
      - `Modernizr <http://modernizr.com/>`_
      - ?

    * - :pypi:`js.raphael`
      - `Raphael <http://raphaeljs.com/>`_
      - ?

    * - :pypi:`js.spin`
      - `spin.js <http://fgnass.github.com/spin.js/>`_
      - ?

    * - :pypi:`js.sugar`
      - `Sugar <http://sugarjs.com/>`_
      - `GitHub <https://github.com/disko/js.sugar>`__

    * - :pypi:`js.tinymce`
      - `TinyMCE <http://tinymce.moxiecode.com>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.tinymce>`__

    * - :pypi:`js.underscore`
      - `underscore.js <http://documentcloud.github.com/underscore/>`_
      - ?

    * - :pypi:`js.yui`
      - the `YUI Library <http://developer.yahoo.com/yui>`_
      - `Bitbucket <http://bitbucket.org/fanstatic/js.yui>`__

Follow the instructions in the :doc:`development section <development>` to learn how to package your own library.
